@@ -36,6 +36,9 @@ use {
 
 pub const DEFAULT_TPU_COALESCE_MS: u64 = 5;
 
+// allow multiple connections for NAT and any open/close overlap
+pub const MAX_QUIC_CONNECTIONS_PER_IP: usize = 8;
+
 pub struct TpuSockets {
     pub transactions: Vec<UdpSocket>,
     pub transaction_forwards: Vec<UdpSocket>,
@@ -108,6 +111,7 @@ impl Tpu {
             cluster_info.my_contact_info().tpu.ip(),
             packet_sender,
             exit.clone(),
+            MAX_QUIC_CONNECTIONS_PER_IP,
         )
         .unwrap();
 
